@@ -16,7 +16,6 @@ import threading
 import warnings
 
 from oslo_config import cfg
-from positional import positional
 import six
 
 from keystoneclient import _discover
@@ -366,7 +365,6 @@ class BaseIdentityPlugin(base.BaseAuthPlugin):
     def get_project_id(self, session, **kwargs):
         return self.get_access(session).project_id
 
-    @positional()
     def get_discovery(self, session, url, authenticated=None):
         """Return the discovery object for a URL.
 
